/*
 * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.spi.ToolProvider;

public class JtregJextractPython {
    private static final ToolProvider JEXTRACT = ToolProvider.findFirst("jextract")
        .orElseThrow(() ->
            new RuntimeException("jextract tool not found")
        );

    private static final Path outputDir = Paths.get(System.getProperty("test.classes", "."));

    public static int main(String[] args) {
        int result = JEXTRACT.run(System.out, System.err,
            "-torg.python",  "-lpython2.7",
            "-rpath=/System/Library/Frameworks/Python.framework/Versions/2.7/lib/",
            "--exclude-symbols=Py_FindMethod|_Py.*|PyBuffer_SizeFromFormat", // missing symbols
            "--exclude-symbols=Py.*_FromFormatV|PyOS_vsnprintf|Py.*VaParse.*|Py_VaBuild.*", // __va_list_tag
            "-d=" + outputDir.toAbsolutePath(),
            "/usr/include/stdio.h", "/usr/include/_stdio.h", "/usr/include/stdlib.h", "/usr/include/sys/signal.h",
            "/usr/include/python2.7/Python.h");

        if (result != 0) {
            throw new RuntimeException(JEXTRACT.name() + " returns non-zero value");
        }
        return result;
    }
}
